==> rhdm-7.8.0-sources.zip: rhba-7.8.0.GA-src/org.kie.workbench-kie-wb-common-7.39.0.Final-7.8.0/kie-wb-common-dmn/kie-wb-common-dmn-client/src/test/java/org/kie/workbench/common/dmn/client/editors/included/grid/DefaultCardComponentTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.dmn.client.editors.included.grid;

import com.google.gwtmockito.GwtMockitoTestRunner;
import org.junit.runner.RunWith;
import org.kie.workbench.common.dmn.client.editors.included.DefaultIncludedModelActiveRecord;

import static org.mockito.Mockito.mock;

@RunWith(GwtMockitoTestRunner.class)
public class DefaultCardComponentTest extends BaseCardComponentTest<DefaultCardComponent, DefaultCardComponent.ContentView, DefaultIncludedModelActiveRecord> {

    @Override
    protected DefaultCardComponent.ContentView getCardView() {
        return mock(DefaultCardComponent.ContentView.class);
    }

    @Override
    protected DefaultCardComponent getCard(final DefaultCardComponent.ContentView cardView) {
        return new DefaultCardComponent(cardView, refreshDecisionComponentsEvent);
    }

    @Override
    protected Class<DefaultIncludedModelActiveRecord> getActiveRecordClass() {
        return DefaultIncludedModelActiveRecord.class;
    }
}

==> rhdm-7.12.1-sources.zip: rhba-7.12.1.GA-src/org.kie.workbench-kie-wb-common-7.59.0.Final-7.12.1/kie-wb-common-dmn/kie-wb-common-dmn-client/src/test/java/org/kie/workbench/common/dmn/client/editors/included/grid/DefaultCardComponentTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.dmn.client.editors.included.grid;

import com.google.gwtmockito.GwtMockitoTestRunner;
import org.junit.runner.RunWith;
import org.kie.workbench.common.dmn.client.editors.included.BaseIncludedModelActiveRecord;
import org.kie.workbench.common.dmn.client.editors.included.DefaultIncludedModelActiveRecord;

import static org.mockito.Mockito.mock;

@RunWith(GwtMockitoTestRunner.class)
public class DefaultCardComponentTest extends BaseCardComponentTest<DefaultCardComponent, DefaultCardComponent.ContentView, DefaultIncludedModelActiveRecord> {

    @Override
    protected DefaultCardComponent.ContentView getCardView() {
        return mock(DefaultCardComponent.ContentView.class);
    }

    @Override
    protected DefaultCardComponent getCard(final DefaultCardComponent.ContentView cardView) {
        return new DefaultCardComponent(cardView, refreshDecisionComponentsEvent);
    }

    @Override
    protected Class<DefaultIncludedModelActiveRecord> getActiveRecordClass() {
        return DefaultIncludedModelActiveRecord.class;
    }

    @Override
    protected BaseIncludedModelActiveRecord prepareIncludedModelMock() {
        return mock(DefaultIncludedModelActiveRecord.class);
    }
}
